@@ -13,17 +13,17 @@ import pickle
 import time
 
 from datetime import datetime, timedelta
-from typing import Any, Iterator
+from typing import Any, Generic, Iterator, Optional
 
 from .funcs import setup_path
-from .types import hmsValue, pathLike
+from .types import T, hmsValue, pathLike
 
 
-class ObjectSaver:
+class ObjectSaver(Generic[T]):
     """オブジェクトを保存するファイルを扱うクラスです。
 
     Properties:
-        obj (Any): ファイルに保存されているオブジェクト。
+        obj (T | None): ファイルに保存されているオブジェクト。
     """
 
     def __init__(self, file: pathLike) -> None:
@@ -57,16 +57,18 @@ class ObjectSaver:
         Returns:
             Any: 復元されたオブジェクト。
         """
+        if not pickle_str:
+            return None
         stb = base64.b64decode(pickle_str.encode())
         return pickle.loads(stb)
 
-    def load_file(self) -> Any:
+    def load_file(self) -> Optional[T]:
         """ファイルに保存されているデータを読み込み、取得します。
 
         ファイルが存在しなかった場合にはNoneを保存したファイルを生成し、Noneを返します。
 
         Returns:
-            Any: ファイルに保存されていたオブジェクト。
+            Optional[T]: ファイルに保存されていたオブジェクト。
         """
         file = self.__file
         if file.exists():
@@ -76,13 +78,13 @@ class ObjectSaver:
             self.save_file(None)
         return None
 
-    def save_file(self, obj: Any) -> bool:
+    def save_file(self, obj: Optional[T]) -> bool:
         """ファイルにobjを保存し、成否を返します。
 
         また、obj属性を更新します。
 
         Args:
-            obj (Any): 保存したいオブジェクト。
+            obj (Optional[T]): 保存したいオブジェクト。
 
         Returns:
             bool: 保存の成否。
@@ -97,7 +99,7 @@ class ObjectSaver:
             return False
 
     @property
-    def obj(self) -> Any:
+    def obj(self) -> Optional[T]:
         """ファイルに保存されているオブジェクト。
 
         新規ファイルでインスタンス生成した場合の初期値はNoneになります。
