@@ -10,12 +10,12 @@ __all__ = (
 )
 
 from pathlib import Path
-from typing import TypeVar
+from typing import Tuple, TypeVar, Union
 
 # ジェネリクス
 T = TypeVar("T")
 FLOAT_INT = TypeVar("FLOAT_INT", float, int)
 
 # タイプエイリアス
-hmsValue = tuple[int, int, float]
-pathLike = Path | str
+hmsValue = Tuple[int, int, float]
+pathLike = Union[Path, str]
